function [segimg, top_slice, bot_slice, sumslices,zflip] = preprocess(img, imgFile, psfPath, downsample, adherent, top_thresh, bot_thresh, display)
% Copyright (C) 2006  Murphy Lab
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

%Created by Devin Sullivan 3/21/13 moved from being a subfunction of
%seg_cell_and_nucleus.m


    
% Load PSFs
infPSF = imfinfo( psfPath);

psf = zeros( infPSF(1).Height, infPSF(1).Width, length(infPSF));

for I=1:length(infPSF)
    psf(:,:,I)=imread(psfPath,I);
end


psf = psf.^2; % Approximate confocal PSF

%D. Sullivan 3/21/13 initialize the z flip to 0
zflip = 0;

% downsample PDFs and images as specified by user
if exist(imgFile,'file')
    load(imgFile)
else
    fprintf(1,'%s\n','Downsampling PSF and image'); tic;
    psf = ml_downsize(psf,downsample,'average');
    resizeimg = ml_downsize(img,downsample,'average'); toc
    clear dnaim3
    fprintf(1,'%s\n','Deconvolving image'); tic;
    [image,psf2] = deconvblind(resizeimg,psf); toc
%    save(dnafile,'dna_image','dnaPSF2');
end


fprintf(1,'%s\n','Segmenting image'); tic;
sumslices = cumsum(squeeze(sum(sum(image))));
sumslices = sumslices/sumslices(end);
bot_slice=find(sumslices> bot_thresh); %0.05, 0.02
bot_slice=bot_slice(1);
top_slice=find(sumslices< top_thresh); %0.95, 0.98
top_slice=top_slice(end);
bot_slice=max(bot_slice,bot_slice);
top_slice=min(top_slice,top_slice);

fprintf(1,'Total slices=%i, Bottom slice=%i, Top slice=%i\n',length(sumslices),bot_slice,top_slice);

mask = image > ml_rcthreshold(image(:));
for i = 1:size(mask,3)
    mask(:,:,i) = bwfill(mask(:,:,i), 'holes');
end
mask = repmat(sum(mask,3), [1,1,size(mask,3)]) > 0;

segimg = region_seg(image, mask, 1000, 0.7, 0, 0);

segimg = ml_findmainobj(segimg);


% segimg = active3Dsegment(image, bot_slice, top_slice,display,[], 1);

if adherent %false, <param>
    %D. Sullivan  3/21/13 check if image is right side up.
    %since we expect the cell to generally get larger at the bottom for
    %adherent cell lines, if the slope of the areas is positive we should 
    %flip the order

    %get total cell area per slice
    areas = squeeze(sum(sum(segimg)));
    %eliminate ones that are not in the cell
    cellareas = areas(areas~=0);
    %P = coefficients P(1)*X+P(2)
    P = polyfit([1:length(cellareas)],cellareas',1);
    if P(1)>0
        %set zflip flag
        zflip = 1;
        segimg = flipdim(segimg,3);
    end
   [bot_slice,top_slice]=fixadherent(segimg,bot_slice,top_slice);
end
clear image
toc

    
end